==> rutorrent-3.9.tar.gz: ruTorrent-3.9/lang/da.js <==
﻿/*
 * Danish language file.
 *
 * Initial Author: Denhart (Denhart@Denhart.dk)
 *
 * Author: 
 */

var theUILang =
{
 General			: "Generelt",
 Downloads			: "Downloads",
 Connection			: "Forbindelse",
 BitTorrent			: "BitTorrent",
 Advanced			: "Avanceret",
 User_Interface 		: "Brugerflade",
 Confirm_del_torr		: "Bekræft når du sletter torrents",
 Update_GUI_every		: "Opdater GUI hvert",
 ms				: "ms",
 Alt_list_bckgnd		: "Alternativ liste baggrundsfarve",
 Show_cat_start 		: "Vis kategorier ved start",
 Show_det_start 		: "Vis details ved start",
 Dnt_start_down_auto		: "Start ikke overførslen automatisk",
 Listening_Port 		: "Port",
 Port_f_incom_conns		: "Port til anvendes af indgående forbindelser",
 Rnd_port_torr_start		: "Tilfældig port hver gang rTorrent starter",
 Type				: "Type",
 Bandwidth_Limiting		: "Båndbredde Begrænsning",
 Global_max_upl 		: "Global maksimal upload hastighed",
 unlimited			: "ubegrænset",
 Glob_max_downl 		: "Global maximum download hastighed",
 Add_bittor_featrs		: "Yderligere BitTorrent Features",
 En_DHT_ntw			: "Aktiver DHT Netværk",
 Peer_exch			: "Peer udvekslingen",
 Ip_report_track		: "IP/Hostname at rapportere til tracker",
 Disabled			: "Deaktiveret",
 Enabled			: "Aktiveret",
 ruTorrent_settings		: "Indstillinger",
 Doesnt_support 		: "ruTorrent virker ikke til din browser.",
 Name				: "Navn",
 Status 			: "Status",
 Size				: "Størrelse",
 Done				: "Færdig",
 Downloaded			: "Downloadet",
 Uploaded			: "Uploadet",
 Ratio				: "Ratio",
 DL				: "DL",
 UL				: "UL",
 ETA				: "ETA",
 Label				: "Etiket",
 Peers				: "Peers",
 Seeds				: "Seeds",
 Remaining			: "Tilbage",
 Priority			: "Prioritet",
 Not_torrent_file		: "Filen skal være en .torrent fil.",
 Pausing			: "Pausing",
 Seeding			: "Seeding",
 Downloading			: "Downloading",
 Checking			: "Checking",
 Error				: "Fejl",
 Queued 			: "I kø",
 Finished			: "Færdig",
 Stopped			: "Stoppet",
 Request_timed_out		: "Anmodningen om at rTorrent har timedout.",
 Start				: "Start",
 Pause				: "Pause",
 Stop				: "Stop",
 Force_recheck			: "Tving Re-check",
 New_label			: "Ny Etiket...",
 Remove_label			: "Fjern Etiket",
 Labels 			: "Etiketter",
 Remove 			: "Fjern",
 Delete_data			: "Slet Data",
 Remove_and			: "Fjern og",
 Details			: "Detaljer...",
 Properties			: "Egenskaber...",
 of				: "ud af", //this two creates line
 connected			: "tilsluttet", //  XX of YY connected
 High_priority			: "Høj",
 Normal_priority		: "Normal",
 Low_priority			: "Lav",
 Dont_download			: "Stop Download",
 Files				: "Filer",
 Logger 			: "Log",
 s				: "s", // part of "KB/s"
 bytes				: "bytes",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Indlæser...",
 Torrent_file			: "Torrent fil",
 Torrent_URL			: "Torrent URL",
 Torrent_properties		: "Torrent Egenskaber",
 Trackers			: "Trackers",
 Bandwidth_sett 		: "Båndbredde Indstillinger",
 Number_ul_slots		: "Antal upload slots: [blank: standard]",
 Peer_ex			: "Peer udveksling",
 Enter_label_prom		: "Indtast den nye etiket for de udvalgte torrents",
 Remove_torrents		: "Fjern Torrent(s)",
 Rem_torrents_prompt		: "Vil du virkelig fjerne den/de valgte torrent(s)?",
 All				: "Alle",
 Active 			: "Aktive",
 Inactive			: "Inaktive",
 No_label			: "Ingen Etiket",
 Transfer			: "Transfer",
 Time_el			: "Tid forløbet",
 Share_ratio			: "Delings Ratio",
 Down_speed			: "Download hastighed",
 Ul_speed			: "Upload hastighed",
 Wasted 			: "Spildt",
 Tracker			: "Tracker",
 Track_URL			: "Tracker URL",
 Track_status			: "Tracker Status",
 Created_on			: "Lavet på",
 Save_as			: "Gem Som",
 Comment			: "Kommentar",
 add_button			: "Tilføj Fil",
 add_url			: "Tilføj URL",
 ok				: "OK",
 Cancel 			: "Annuller",
 mnu_add			: "Tilføj Torrent",
 mnu_remove			: "Fjern",
 mnu_start			: "Start",
 mnu_pause			: "Pause",
 mnu_stop			: "Stop",
 mnu_rss			: "RSS Downloader",
 mnu_settings			: "Indstillinger",
 mnu_search			: "Søg",
 mnu_lang			: "Sprog",
 torrent_add			: "Tilføj Torrent", /*Caption of torrent add box*/
 time_w 			: "w ", /*for x weeks*/
 time_d 			: "d ", /*for x days remaining*/
 time_h 			: "h ", /*for x hours remaining*/
 time_m 			: "m ", /*for x minutes remaining*/
 time_s 			: "s ", /*for x seconds remaining*/
 Base_directory 		: "Directory",
 Number_Peers_min		: "Minimum antal peers",
 Number_Peers_max		: "Maksimum antal peers",
 Tracker_Numwant		: "Ønsket antal peers",
 Number_Peers_For_Seeds_min	: "Minimum antal peers til seeding",
 Number_Peers_For_Seeds_max	: "Maksimum antal peers til seeding",
 Enable_port_open		: "Åben lyttende port",
 dht_port			: "UDP port brugt til DHT",
 Other_Limiting 		: "Andre Begrænsninger",
 Number_dl_slots		: "Antal af download slots",
 Glob_max_memory		: "Maksimalt hukommelses brug",
 Glob_max_files 		: "Maksimalt antal af åbne filer",
 Glob_max_http			: "Maksimalt antal af åbne http forbindelser",
 Other_sett			: "Andre",
 Directory_For_Dl		: "Standard mappe til downloads",
 Check_hash			: "Valider hash efter download",
 Hash				: "Hash",
 DisableTracker 		: "Slå fra",
 EnableTracker			: "Slå til",
 ClientVersion			: "Klient",
 Flags				: "Flag",
 ReqTimeout			: "Forespørgsels timeout",
 GetTrackerMessage		: "Modtag beskeder fra tracker",
 Help				: "Hjælp",
 Speed				: "Hastighed",
 Dont_add_tname 		: "Tilføj ikke torrentens navn til stien",
 Free_Disk_Space		: "Ledig Disk Plads",
 badXMLRPCVersion		: "rTorrent er kompileret med en forkert version af xmlrpc-c biblioteket, som ikke har support for i8. Versionen skal være >=1.11. Noget funktionalitet vil ikke være tilgængelig.",
 badLinkTorTorrent		: "Ingen forbindelse til rTorrent. Check om rtorrent kører. Check $scgi_port og $scgi_host settings i config.php og scgi_port i rTorrent konfigurations filen.",
 badUploadsPath 		: "Webserverens bruger har ikke read/write/execute adgang til torrents mappen. Du kan ikke tilføje torrents via ruTorrent.",
 badSettingsPath		: "Webserverens bruger har ikke read/write/execute adgang til indstillings mappen. ruTorrents indstillinger kan ikke gemmes.",
 mnu_help			: "Hjælp",
 badUploadsPath2		: "rTorrent skal have read/execute adgang til torrents mappen. Du kan ikke tilføje torrents via ruTorrent.",
 View				: "Vis",
 AsList 			: "Som Liste",
 AsTree 			: "Som Træ",
 Group				: "Gruppe",
 SuperSeed			: "Super-seed",
 badTestPath			: "rTorrent brugeren skal have read/execute adgang til filen ./test.sh",
 badSettingsPath2		: "rTorrent brugeren skal have read/write/execute adgang til indstillings mappen.",
 scrapeDownloaded		: "Downloadet",
 Total				: "Total",
 PCRENotFound			: "PHP PCRE modul er ikke installeret. ruTorrent kan ikke virke uden.",
 addTorrentSuccess		: "Torrenten tilføjet uden problemer.",
 addTorrentFailed		: "Tilføjelse af torrent fejlede.",
 pnlState			: "State",
 newLabel			: "Ny Label",
 enterLabel			: "Enter Label",
 UIEffects			: "Vis effekter på UI elementer",
 Plugins			: "Plugins",
 plgName			: "Navn",
 plgStatus			: "Status",
 plgLoaded			: "Loadet",
 plgDisabled			: "Ikke loadet",
 plgVersion			: "Version",
 plgAuthor			: "Ejer",
 plgDescr			: "Beskrivelse",
 mnu_go 			: "Go",
 pluginCantStart		: "Plugin kunne ikke starte.",
 doFastResume			: "Hurtig genoptagelse",
 innerSearch			: "Lokale Torrents",
 removeTeg			: "Fjern tag",
 errMustBeInSomeHost		: "ruTorrent og rTorrent skal være installeret på den samme makine. Plugin kommer ikke til at virke.",
 warnMustBeInSomeHost		: "ruTorrent og rTorrent skal være installeret på den samme makine. Noget funktionalitet vil ikke være tilgængelig.",
 plgShutdown			: "Unload",
 limit				: "Grænse",
 speedList			: "Hastigheds Popup Liste (kommasepareret)",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignorer beskeder om timeouts",
 fullTableRender		: "Render store tabeller fuldt",
 showScrollTables		: "Vis tabelindhold imens der rulles",
 idNotFound			: "rTorrent brugeren kan ikke få adgang til 'id' programmet. Noget funktionalitet vil ikke være tilgængelig.",
 gzipNotFound			: "Webserverens bruger har ikke adgang til 'gzip' programmet. ruTorrent kan ikke virke uden",
 cantObtainUser 		: "ruTorrent kan ikke finde UID af rTorrent brugeren. Noget funktionalitet vil ikke være tilgængelig.",
 retryOnErrorTitle		: "Hvis rTorrent ikke er tilgængelig, prøv igen efter",
 retryOnErrorList		: { 0: "Prøv ikke igen", 30: "30 sek", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent brugeren kan ikke få adgang til 'stat' programet. Noget funktionalitet vil ikke være tilgængelig.",
 statNotFoundW			: "Webserverens bruger har ikke adgang til 'stat' programmet. Noget funktionalitet vil ikke være tilgængelig.",
 badrTorrentVersion		: "Plugin kræver rTorrent version >=",
 badPHPVersion			: "Plugin kræver PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin virker ikke. rTorrent brugeren kan ikke få adgang til det eksterne program",
 rTorrentExternalNotFoundWarning: "Noget funktionalitet vil ikke være tilgængelig. rTorrent brugeren kan ikke få adgang til det eksterne program",
 webExternalNotFoundError	: "Plugin virker ikke. Webserverens bruger kan ikke få adgang til det eksterne program",
 webExternalNotFoundWarning	: "Noget funktionalitet vil ikke være tilgængelig. Webserverens bruger kan ikke få adgang til det eksterne program",
 rTorrentBadScriptPath		: "Plugin virker ikke. rTorrent brugeren skal have read/execute adgang til filen",
 rTorrentBadPHPScriptPath	: "Plugin virker ikke. rTorrent brugeren skal have read adgang til filen",
 dependenceError		: "Plugin virker ikke. Det kræver plugin(s)",
 peerAdd			: "Tilføj Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Detaljer",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent listen er ikke tilgængelig endnu, forbindelsen til rTorrent er ikke etableret.",
 yes				: "ja",
 no				: "nej",
 DateFormat			: "Dato format",
 DLStrategy			: "Download Strategi",
 prioritizeFirst		: "Leading Chunk Først",
 prioritizeLast 		: "Trailing Chunk Først",
 prioritizeNormal		: "Normal",
 updateTracker			: "Opdater Trackers",
 scrapeUpdate			: "Sidst Opdateret",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch til 'Log' fanen",
 showLabelSize			: "Show label size",
 phpParameterUnavailable	: "PHP directive register_argc_argv er sat til OFF. Skift til ON, ellers vil nogle plugins ikke virke korrekt.",
 addTorrentFailedURL		: "Kunne ikke tilføje torrent. Kan ikke forbine til URL.",
 addTorrentFailedFile		: "Kunne ikke tilføje torrent. Den modtagende fil er ikke en valid torrent fil.",
 addTorrentFailedDirectory	: "Kunne ikke tilføje torrent. Ukorrekt download mappe var specificeret.",
 plgLaunch			: "Start",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Noget funktionalitet vil ikke være tilgængelig. PHP udviddelse skal installeres",
 phpExtensionNotFoundError	: "Plugin virker ikke. PHP udviddelse skal installeres",
 trkPrivate			: "Privat",
 dontSet			: "Sæt ikke",
 webBadSessionError		: "Plugin virker ikke. Webserverens bruger skal have execute adgang til rtorrents session mappe",
 webBadSessionWarning		: "Noget funktionalitet vil ikke være tilgængelig. Webserverens bruger skal have execute adgang til rtorrents session mappe",
 Developers			: "Udviklere",
 Check_new_version		: "Check for ny version",
 here				: "her",
 Num_No 			: "Nr.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "Denne skærm",
 About_program			: "Om ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details 		: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Slet nuværende torrent(s)",
 Select_all			: "Vælg alle",
 Deselect_all			: "Fravælg alle",
 showSpeedInTitle		: "Vis hastighed i titlen",
 badTempPath 			: "Webserverens bruger har ikke read/write/execute adgang til tmp mappen. ruTorrent virker derfor ikke.",
 badTempPath2			: "rTorrent brugeren skal have read/execute adgang til tmp mappen. ruTorrent virker derfor ikke.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files 		: "Queue files recreation",
 Address			: "Adresse",
 PeerDL 			: "Peer DL",
 PeerDownloaded 		: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags"
};

==> rutorrent-4.0.4.tar.gz: ruTorrent-4.0.4/lang/da.js <==
﻿/*
 * Danish language file.
 *
 * Initial Author: Denhart (Denhart@Denhart.dk)
 *
 * Author: 
 */

var theUILang =
{
 General			: "Generelt",
 Downloads			: "Downloads",
 Connection			: "Forbindelse",
 BitTorrent			: "BitTorrent",
 Format			: "Format",
 Advanced			: "Avanceret",
 User_Interface			: "Brugerflade",
 Confirm_del_torr		: "Bekræft når du sletter torrents",
 Update_GUI_every		: "Opdater GUI hvert",
 ms				: "ms",
 Alt_list_bckgnd		: "Alternativ liste baggrundsfarve",
 Show_cat_start			: "Vis kategorier ved start",
 Show_det_start			: "Vis details ved start",
 KeepSearches			: "Keep searches",
 KeepSelectedTab			: "Keep selected tab",
 KeepSelectedLabels		: "Keep selected labels",
 Dnt_start_down_auto		: "Start ikke overførslen automatisk",
 Listening_Port			: "Port",
 Port_f_incom_conns		: "Port til anvendes af indgående forbindelser",
 Rnd_port_torr_start		: "Tilfældig port hver gang rTorrent starter",
 Type				: "Type",
 Bandwidth_Limiting		: "Båndbredde Begrænsning",
 Global_max_upl			: "Global maksimal upload hastighed",
 unlimited			: "ubegrænset",
 Glob_max_downl			: "Global maximum download hastighed",
 Add_bittor_featrs		: "Yderligere BitTorrent Features",
 En_DHT_ntw			: "Aktiver DHT Netværk",
 Peer_exch			: "Peer udvekslingen",
 Ip_report_track		: "IP/Hostname at rapportere til tracker",
 Disabled			: "Deaktiveret",
 Enabled			: "Aktiveret",
 ruTorrent_settings		: "Indstillinger",
 Doesnt_support			: "ruTorrent virker ikke til din browser.",
 Name				: "Navn",
 Status				: "Status",
 Size				: "Størrelse",
 Done				: "Færdig",
 Downloaded			: "Downloadet",
 Uploaded			: "Uploadet",
 Ratio				: "Ratio",
 DL				: "DL",
 UL				: "UL",
 ETA				: "ETA",
 Label				: "Etiket",
 Peers				: "Peers",
 Seeds				: "Seeds",
 Remaining			: "Tilbage",
 Priority			: "Prioritet",
 Not_torrent_file		: "Filen skal være en .torrent fil.",
 Pausing			: "Pausing",
 Seeding			: "Seeding",
 Downloading			: "Downloading",
 Checking			: "Checking",
 Error				: "Fejl",
 Queued				: "I kø",
 Finished			: "Færdig",
 Stopped			: "Stoppet",
 Request_timed_out		: "Anmodningen om at rTorrent har timedout.",
 Start				: "Start",
 Pause				: "Pause",
 Stop				: "Stop",
 Force_recheck			: "Tving Re-check",
 New_label			: "Ny Etiket...",
 Remove_label			: "Fjern Etiket",
 Labels				: "Etiketter",
 Remove				: "Fjern",
 Delete_data			: "Slet Data",
 Remove_and			: "Fjern og",
 Details			: "Detaljer...",
 Properties			: "Egenskaber...",
 of				: "ud af", // this two creates line
 connected			: "tilsluttet", // XX of YY connected
 High_priority			: "Høj",
 Normal_priority		: "Normal",
 Low_priority			: "Lav",
 Dont_download			: "Stop Download",
 Files				: "Filer",
 Logger				: "Log",
 s				: "s", // part of "KB/s"
 bytes				: "bytes",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Indlæser...",
 Torrent_file			: "Torrent fil",
 Torrent_URL			: "Torrent URL",
 Torrent_properties		: "Torrent Egenskaber",
 Trackers			: "Trackers",
 Bandwidth_sett			: "Båndbredde Indstillinger",
 Number_ul_slots		: "Antal upload slots: [blank: standard]",
 Peer_ex			: "Peer udveksling",
 Enter_label_prom		: "Indtast den nye etiket for de udvalgte torrents",
 Remove_torrents		: "Fjern Torrent(s)",
 Rem_torrents_prompt		: "Vil du virkelig fjerne den/de valgte torrent(s)?",
 All				: "Alle",
 Active				: "Aktive",
 Inactive			: "Inaktive",
 No_label			: "Ingen Etiket",
 Transfer			: "Transfer",
 Time_el			: "Tid forløbet",
 Share_ratio			: "Delings Ratio",
 Down_speed			: "Download hastighed",
 Ul_speed			: "Upload hastighed",
 Wasted				: "Spildt",
 Tracker			: "Tracker",
 Track_URL			: "Tracker URL",
 Track_status			: "Tracker Status",
 Created_on			: "Lavet på",
 Save_as			: "Gem Som",
 Comment			: "Kommentar",
 add_button			: "Tilføj Fil",
 add_url			: "Tilføj URL",
 ok				: "OK",
 Cancel				: "Annuller",
 mnu_add			: "Tilføj Torrent",
 mnu_remove			: "Fjern",
 mnu_start			: "Start",
 mnu_pause			: "Pause",
 mnu_stop			: "Stop",
 mnu_rss			: "RSS Downloader",
 mnu_settings			: "Indstillinger",
 mnu_search			: "Søg",
 mnu_lang			: "Sprog",
 torrent_add			: "Tilføj Torrent", /*Caption of torrent add box*/
 time_w				: "w ", /*for x weeks*/
 time_d				: "d ", /*for x days remaining*/
 time_h				: "h ", /*for x hours remaining*/
 time_m				: "m ", /*for x minutes remaining*/
 time_s				: "s ", /*for x seconds remaining*/
 Base_directory			: "Directory",
 Number_Peers_min		: "Minimum antal peers",
 Number_Peers_max		: "Maksimum antal peers",
 Tracker_Numwant		: "Ønsket antal peers",
 Number_Peers_For_Seeds_min	: "Minimum antal peers til seeding",
 Number_Peers_For_Seeds_max	: "Maksimum antal peers til seeding",
 Enable_port_open		: "Åben lyttende port",
 dht_port			: "UDP port brugt til DHT",
 Other_Limiting			: "Andre Begrænsninger",
 Number_dl_slots		: "Antal af download slots",
 Glob_max_memory		: "Maksimalt hukommelses brug",
 Glob_max_files			: "Maksimalt antal af åbne filer",
 Glob_max_http			: "Maksimalt antal af åbne http forbindelser",
 Open_label         : "Åben",
 Other_sett			: "Andre",
 Directory_For_Dl		: "Standard mappe til downloads",
 Check_hash			: "Valider hash efter download",
 Hash				: "Hash",
 DisableTracker			: "Slå fra",
 EnableTracker			: "Slå til",
 ClientVersion			: "Klient",
 Flags				: "Flag",
 ReqTimeout			: "Forespørgsels timeout",
 GetTrackerMessage		: "Modtag beskeder fra tracker",
 Help				: "Hjælp",
 Speed				: "Hastighed",
 Dont_add_tname			: "Tilføj ikke torrentens navn til stien",
 Free_Disk_Space		: "Ledig Disk Plads",
 badXMLRPCVersion		: "rTorrent er kompileret med en forkert version af xmlrpc-c biblioteket, som ikke har support for i8. Versionen skal være >= 1.11. Noget funktionalitet vil ikke være tilgængelig.",
 badLinkTorTorrent		: "Ingen forbindelse til rTorrent. Check om rtorrent kører. Check $scgi_port og $scgi_host settings i config.php og scgi_port i rTorrent konfigurations filen.",
 badUploadsPath			: "Webserverens bruger har ikke read/write/execute adgang til torrents mappen. Du kan ikke tilføje torrents via ruTorrent.",
 badSettingsPath		: "Webserverens bruger har ikke read/write/execute adgang til indstillings mappen. ruTorrents indstillinger kan ikke gemmes.",
 mnu_help			: "Hjælp",
 badUploadsPath2		: "rTorrent skal have read/execute adgang til torrents mappen. Du kan ikke tilføje torrents via ruTorrent.",
 View				: "Vis",
 AsList				: "Som Liste",
 AsTree				: "Som Træ",
 Group				: "Gruppe",
 SuperSeed			: "Super-seed",
 badTestPath			: "rTorrent brugeren skal have read/execute adgang til filen ./test.sh",
 badSettingsPath2		: "rTorrent brugeren skal have read/write/execute adgang til indstillings mappen.",
 scrapeDownloaded		: "Downloadet",
 Total				: "Total",
 PCRENotFound			: "PHP PCRE modul er ikke installeret. ruTorrent kan ikke virke uden.",
 addTorrentSuccess		: "Torrenten tilføjet uden problemer.",
 addTorrentFailed		: "Tilføjelse af torrent fejlede.",
 pnlState			: "State",
 newLabel			: "Ny Label",
 enterLabel			: "Enter Label",
 UIEffects			: "Vis effekter på UI elementer",
 Plugins			: "Plugins",
 plgName			: "Navn",
 plgStatus			: "Status",
 plgLoaded			: "Loadet",
 plgDisabled			: "Ikke loadet",
 plgVersion			: "Version",
 plgAuthor			: "Ejer",
 plgDescr			: "Beskrivelse",
 mnu_go				: "Go",
 pluginCantStart		: "Plugin kunne ikke starte.",
 doFastResume			: "Hurtig genoptagelse",
 innerSearch			: "Lokale Torrents",
 removeTeg			: "Fjern tag",
 errMustBeInSomeHost		: "ruTorrent og rTorrent skal være installeret på den samme makine. Plugin kommer ikke til at virke.",
 warnMustBeInSomeHost		: "ruTorrent og rTorrent skal være installeret på den samme makine. Noget funktionalitet vil ikke være tilgængelig.",
 plgShutdown			: "Unload",
 limit				: "Grænse",
 speedList			: "Hastigheds Popup Liste (kommasepareret)",
 DecimalPlacesSizes		: "Decimal Places of Sizes",
 CatListSizeDecimalPlaces	: "In category list",
 TableSizeDecimalPlaces	: "In tables",
 DetailsSizeDecimalPlaces	: "In general tab",
 OtherSizeDecimalPlaces	: "Other",
 Default	: "Default",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignorer beskeder om timeouts",
 fullTableRender		: "Render store tabeller fuldt",
 showScrollTables		: "Vis tabelindhold imens der rulles",
 idNotFound			: "rTorrent brugeren kan ikke få adgang til 'id' programmet. Noget funktionalitet vil ikke være tilgængelig.",
 gzipNotFound			: "Webserverens bruger har ikke adgang til 'gzip' programmet. ruTorrent kan ikke virke uden.",
 cantObtainUser			: "ruTorrent kan ikke finde UID af rTorrent brugeren. Noget funktionalitet vil ikke være tilgængelig.",
 retryOnErrorTitle		: "Hvis rTorrent ikke er tilgængelig, prøv igen efter",
 retryOnErrorList		: { 0: "Prøv ikke igen", 30: "30 sek", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent brugeren kan ikke få adgang til 'stat' programet. Noget funktionalitet vil ikke være tilgængelig.",
 statNotFoundW			: "Webserverens bruger har ikke adgang til 'stat' programmet. Noget funktionalitet vil ikke være tilgængelig.",
 badrTorrentVersion		: "Plugin kræver rTorrent version >=",
 badPHPVersion			: "Plugin kræver PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin virker ikke. rTorrent brugeren kan ikke få adgang til det eksterne program",
 rTorrentExternalNotFoundWarning: "Noget funktionalitet vil ikke være tilgængelig. rTorrent brugeren kan ikke få adgang til det eksterne program",
 webExternalNotFoundError	: "Plugin virker ikke. Webserverens bruger kan ikke få adgang til det eksterne program",
 webExternalNotFoundWarning	: "Noget funktionalitet vil ikke være tilgængelig. Webserverens bruger kan ikke få adgang til det eksterne program",
 rTorrentBadScriptPath		: "Plugin virker ikke. rTorrent brugeren skal have read/execute adgang til filen",
 rTorrentBadPHPScriptPath	: "Plugin virker ikke. rTorrent brugeren skal have read adgang til filen",
 dependenceError		: "Plugin virker ikke. Det kræver plugin(s)",
 peerAdd			: "Tilføj Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Detaljer",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent listen er ikke tilgængelig endnu, forbindelsen til rTorrent er ikke etableret.",
 yes				: "ja",
 no				: "nej",
 DateFormat			: "Dato format",
 DLStrategy			: "Download Strategi",
 prioritizeFirst		: "Leading Chunk Først",
 prioritizeLast			: "Trailing Chunk Først",
 prioritizeNormal		: "Normal",
 updateTracker			: "Opdater Trackers",
 scrapeUpdate			: "Sidst Opdateret",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch til 'Log' fanen",
 showStateLabelSize		: "Show state size",
 showLabelSize			: "Show label size",
 showSearchLabelSize		: "Show search size",
 showCustomLabelTree		: "Show label path tree",
 labelSizeRightAlign		: "Right align size in category list",
 showEmptyPathLabel		: "Show empty path labels",
 showLabelTextOverflow	: "Allow overflow of label text",
 showOpenStatus		: "Show open status in status bar",
 requiresAtLeastRtorrent		: "Requires rTorrent >= {version}", // ... v0.9.7
 phpParameterUnavailable	: "PHP directive register_argc_argv er sat til OFF. Skift til ON, ellers vil nogle plugins ikke virke korrekt.",
 addTorrentFailedURL		: "Kunne ikke tilføje torrent. Kan ikke forbine til URL.",
 addTorrentFailedFile		: "Kunne ikke tilføje torrent. Den modtagende fil er ikke en valid torrent fil.",
 addTorrentFailedDirectory	: "Kunne ikke tilføje torrent. Ukorrekt download mappe var specificeret.",
 plgLaunch			: "Start",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Noget funktionalitet vil ikke være tilgængelig. PHP udviddelse skal installeres",
 phpExtensionNotFoundError	: "Plugin virker ikke. PHP udviddelse skal installeres",
 trkPrivate			: "Privat",
 dontSet			: "Sæt ikke",
 webBadSessionError		: "Plugin virker ikke. Webserverens bruger skal have execute adgang til rtorrents session mappe",
 webBadSessionWarning		: "Noget funktionalitet vil ikke være tilgængelig. Webserverens bruger skal have execute adgang til rtorrents session mappe",
 Developers			: "Udviklere",
 Check_new_version		: "Check for ny version",
 here				: "her",
 Num_No				: "Nr.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "Denne skærm",
 About_program			: "Om ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details			: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Slet nuværende torrent(s)",
 Select_all			: "Vælg alle",
 Deselect_all			: "Fravælg alle",
 showSpeedInTitle		: "Vis hastighed i titlen",
 speedGraphDuration		: "Duration of speed graph",
 speedGraphDurationOptions		: {600: "10 min", 1800: "30 min", 3600: "1 hr", 10800: "3 hrs"},
 badTempPath			: "Webserverens bruger har ikke read/write/execute adgang til tmp mappen. ruTorrent virker derfor ikke.",
 badTempPath2			: "rTorrent brugeren skal have read/execute adgang til tmp mappen. ruTorrent virker derfor ikke.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files			: "Queue Files Recreation",
 Address			: "Adresse",
 PeerDL				: "Peer DL",
 PeerDownloaded			: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags",
 Torrents			: "Torrent(s)",
 copyToClipboardFailed		: "The copy function isn't working in your browser.\nPlease copy this content manually:\n\n",
 copyToClipboardSuccess		: "Copied to clipboard successfully!"
};
